@@ -1,7 +1,8 @@
-
 from .sync import (
     exchange,
     ConversationalComponent,
     generate_session_id,
-    ComponentSession
+    ComponentSession,
 )
+
+from . import config_models as config
